@@ -1,13 +1,18 @@
-from django.conf.urls.defaults import url, patterns
+from django.conf.urls import url, patterns
 
-import kaleo.receivers
-
-from kaleo.views import invite, topoff_all, addto_all, topoff_user, addto_user, invite_stat
+from kaleo.views import (
+    addto_all,
+    addto_user,
+    invite,
+    topoff_all,
+    invite_stat,
+    topoff_user
+)
 
 
-urlpatterns = patterns("",
+urlpatterns = patterns(
+    "",
     url(r"^invite/$", invite, name="kaleo_invite"),
-    
     url(r"^invite-stat/(?P<pk>\d+)/$", invite_stat, name="kaleo_invite_stat"),
     url(r"^topoff/$", topoff_all, name="kaleo_topoff_all"),
     url(r"^topoff/(?P<pk>\d+)/$", topoff_user, name="kaleo_topoff_user"),
